@@ -19,7 +19,7 @@ use Module::Load::Conditional   qw[can_load];
 use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 
 use vars qw[$VERSION];
-$VERSION = "0.9136";
+$VERSION = "0.9144";
 
 $Params::Check::VERBOSE = 1;
 
@@ -205,8 +205,8 @@ sub _build_trees {
     }
 
     ### XXX unpleasant hack. since custom sources uses ->parse_module, we
-    ### already have a special module object with extra meta data. that
-    ### doesn't gelwell with the sqlite storage engine. So, we check 'normal'
+    ### already have a special module object with extra meta data. That
+    ### doesn't go well with the sqlite storage engine. So, we check 'normal'
     ### trees from separate trees, so the engine can treat them differently.
     ### Effectively this means that with the SQLite engine, for now, custom
     ### sources are continuously reparsed =/ -kane
@@ -307,7 +307,7 @@ sub _check_trees {
 
     my $uptodate = 1; # default return value
 
-    for my $name (qw[auth dslip mod]) {
+    for my $name (qw[auth mod]) {
         for my $file ( $conf->_get_source( $name ) ) {
             $self->__check_uptodate(
                 file            => File::Spec->catfile( $path, $file ),
@@ -1035,7 +1035,7 @@ sub _add_custom_module_source {
                 local   => $index,
                 verbose => $verbose,
             ) or do {
-                ### we faild to update it, we probably have an empty
+                ### we failed to update it, we probably have an empty
                 ### possibly silly filename on disk now -- remove it
                 1 while unlink $index;
                 return;
